@@ -1,4 +1,4 @@
-use anyhow::Result;
+use anyhow::{Result, Context};
 use std::io::{self, Write, stdin};
 
 pub fn get_answer(prompt: &str, default: bool) -> Result<bool> {
@@ -6,16 +6,15 @@ pub fn get_answer(prompt: &str, default: bool) -> Result<bool> {
     if default { switch = "(Y/n)"; } else { switch = "(y/N)"; }
     
     let answer_bool;
-
     loop {
         print!("{prompt} {switch}: ");
-        io::stdout().flush().unwrap();
+        io::stdout().flush().context("Unable to flush stdout")?;
 
         let mut answer = String::new();
-        stdin().read_line(&mut answer)?;
+        stdin().read_line(&mut answer).context("Unable to read from stdin")?;
 
         let answer_lowercase = answer.to_lowercase();
-        let first_char = answer_lowercase.chars().next().unwrap();
+        let first_char = answer_lowercase.chars().next().context("Unable to get first character of your answer")?;
         answer_bool = match first_char {
             '\n' => default,
             '\r' => default,
@@ -28,6 +27,5 @@ pub fn get_answer(prompt: &str, default: bool) -> Result<bool> {
         };
         break;
     }
-
     Ok(answer_bool)
 }
\ No newline at end of file
